package com.platform.yijia.controller;

import com.google.gson.Gson;
import com.platform.yijia.pojo.*;
import com.platform.yijia.service.*;
import com.platform.yijia.utils.CodeMsg;
import com.platform.yijia.utils.ResultData;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Random;

/*
 * <Title> IntegralWaresController </Title>
 * <Description> 油站积分商城 </Description>
 * @Author JK
 * @Date 2021年2月24日
 */
@Controller
@RequestMapping("/api")
public class IntegralOrderController {
    @Resource
    private IntegralWaresService integralWaresService;
    @Resource
    private IntegralOrderService integralOrderService;
    @Resource
    private CustomerPointsService customerPointsService;

    //获取油站积分商品信息
    @RequestMapping(value = "/getIntegralWaresInfoList", method = RequestMethod.GET)
    @ResponseBody
    public String getIntegralWaresInfoList(@RequestParam Integer stationId){
        Gson gson =new Gson();
        //返回结果集
        ResultData resultData = null;
        if(stationId !=null){
            IntegralWares integralWares = new IntegralWares();
            integralWares.setStationId(stationId);
            List<IntegralWares> integralWaresInfoList = integralWaresService.getIntegralWaresInfoList(integralWares);
            resultData=ResultData.success(integralWaresInfoList);
        }else{
            resultData=ResultData.error(CodeMsg.REQUEST_FAIL);
        }
        return gson.toJson(resultData);
    }

    //生成积分订单
    @RequestMapping(value = "/insertIntegralOrder", method = RequestMethod.GET)
    @ResponseBody
    public String insertIntegralOrder(@RequestParam IntegralOrder request){
        Gson gson =new Gson();
        //返回结果集
        ResultData resultData = null;
        IntegralOrder integralOrder = new IntegralOrder();
        if(StringUtils.isNotBlank(request.getCustomerName())){
            integralOrder.setCustomerName(request.getCustomerName());
        }
        if(StringUtils.isNotBlank(request.getWaresName())){
            integralOrder.setWaresName(request.getWaresName());
        }
        if(request.getExchangeNum() != null){
            integralOrder.setExchangeNum(request.getExchangeNum());
        }
        if(StringUtils.isNotBlank(request.getUnionId())){
            integralOrder.setUnionId(request.getUnionId());
        }
        //订单规则 时间+6位随机数
        Random random = new Random();
        String str="";
        for(int i=0; i<6; i++){
            str+=random.nextInt(10);
        }
        integralOrder.setIntegralOrderNo(Integer.valueOf(System.nanoTime()+str));
        integralOrder.setExchangeTime(new Date());

        //更新用户积分
        CustomerPoints customerPoints = new CustomerPoints();
        customerPoints.setUnionId(request.getUnionId());
        CustomerPoints customerPointsInfo = customerPointsService.getCustomerPointsInfo(customerPoints);
        //用户剩余积分
        BigDecimal points = new BigDecimal(customerPointsInfo.getPoints()).subtract(new BigDecimal(request.getIntegral()));
        customerPoints.setPoints(Integer.valueOf(points.toString()));
        //用户已消费积分累积
        BigDecimal consumptionPoints = new BigDecimal(customerPointsInfo.getConsumptionPoints()).add(new BigDecimal(request.getIntegral()));
        customerPoints.setConsumptionPoints(Integer.valueOf(consumptionPoints.toString()));
        customerPointsService.updateCustomerPointsInfo(customerPoints);

        boolean b = integralOrderService.insertIntegralOrder(integralOrder);
        if (b){
            resultData=ResultData.success(CodeMsg.SUCCESS);
        }else {
            resultData=ResultData.success(CodeMsg.REQUEST_FAIL);
        }
        return gson.toJson(resultData);
    }

    //获取用户订单列表
    @RequestMapping(value = "/getUserIntegralOrderList", method = RequestMethod.GET)
    @ResponseBody
    public String getUserIntegralOrderList(@RequestParam String unionId){
        Gson gson =new Gson();
        //返回结果集
        ResultData resultData = null;
        if(unionId !=null){
            IntegralOrder integralOrder = new IntegralOrder();
            integralOrder.setUnionId(unionId);
            List<IntegralOrder> integralOrderList = integralOrderService.getUserIntegralOrderList(integralOrder);
            resultData=ResultData.success(integralOrderList);
        }else {
            resultData=ResultData.success(CodeMsg.REQUEST_FAIL);
        }
        return gson.toJson(resultData);
    }

}
